@@ -7,7 +7,7 @@ get.Model <- function(model.available,model.folder)
   }
   if(!file.exists(file.path(model.folder,paste(model.available,".Model.gds",sep=""))))
   {
-    download.file(paste("https://github.com/aromanel/EthSEQ_Data/raw/master/EthSEQ_Models/",model.available,".Model.gds",sep=""),
+    download.file(paste("https://github.com/cibiobcg/EthSEQ_Data/raw/master/EthSEQ_Models/",model.available,".Model.gds",sep=""),
                   file.path(model.folder,paste(model.available,".Model.gds",sep="")))
   }
   return(file.path(model.folder,paste(model.available,".Model.gds",sep="")))
